==> dartdap-0.0.5.tar.gz: test/ad_test.dart <==
import 'package:unittest/unittest.dart';
import 'package:dartdap/dartdap.dart';
import 'package:logging_handlers/logging_handlers_shared.dart';
import 'package:logging/logging.dart';


/**
 * Tests for debugging AD issue
 * Will probably merge into other test tree..
 */

main() async {
  LDAPConnection ldap;
  //var ldapConfig = new LDAPConfiguration("test/ad.yaml","default");
  //var ldapConfig = new LDAPConfiguration("test/ad.yaml","ad389");
  var ldapConfig = new LDAPConfiguration("test/ad.yaml","proxy");
  //var ldapConfig = new LDAPConfiguration("test/ad.yaml","gce");
  //var ldapConfig = new LDAPConfiguration("test/ldap.yaml","default");

  startQuickLogging();
  Logger.root.level = Level.FINEST;


  group('LDAP Search ', ()  {
    // create a connection. Return a future that completes when
    // the connection is available and bound
    setUp( ()  async {
     ldap = await ldapConfig.getConnection();
    });

    tearDown( () async {
      await ldap.close();
    });

//    test('AD bind', () async {
//
//       await ldap.bind();
//    });

    test('AD search', () async {

      //await ldap.bind();

      var f1 = Filter.substring("CN=*");
      //var f2 =  Filter.equals("objectclass", "inetOrgPerson");
      var f2 =  Filter.equals("objectclass", "person");
      //var f2 =  Filter.equals("CN", "foo");

      // equiv ldapsearch
      //ldapsearch -p 2389 -h localhost -D "cn=Directory Manager" -w password \
      //  -b "dc=example,dc=com" -a always \
      //  -s sub "(CN=foo)" dn objectClass
      //


        var result = ldap.search("CN=Users,DC=openrock,DC=org", f2, ["dn"]).stream;
        //var result = ldap.search("dc=example,dc=com", f2, ["dn","objectClass"], sizeLimit:0).stream;
        //var result = ldap.search("DC=openrock,DC=org", f2, []).stream;

        int count = 0;
        var f = result.listen( (entry) {
          ++count;
          print(entry);
        },
        onDone: () {
          print("count=$count");
          },
        onError: (e) {});

      return f;

    });
  });
}

==> dartdap-0.0.7.tar.gz: test/ad_test.dart <==
import 'package:unittest/unittest.dart';
import 'package:dartdap/dartdap.dart';
import 'package:logging_handlers/logging_handlers_shared.dart';
import 'package:logging/logging.dart';


/**
 * Tests for debugging AD issue
 * Will probably merge into other test tree..
 */

main() async {
  LDAPConnection ldap;
  //var ldapConfig = new LDAPConfiguration("test/ad.yaml","default");
  //var ldapConfig = new LDAPConfiguration("test/ad.yaml","ad389");
  var ldapConfig = new LDAPConfiguration("test/ad.yaml","proxy");
  //var ldapConfig = new LDAPConfiguration("test/ad.yaml","gce");
  //var ldapConfig = new LDAPConfiguration("test/ldap.yaml","default");

  startQuickLogging();
  Logger.root.level = Level.FINEST;


  group('LDAP Search ', ()  {
    // create a connection. Return a future that completes when
    // the connection is available and bound
    setUp( ()  async {
     ldap = await ldapConfig.getConnection();
    });

    tearDown( () async {
      await ldap.close();
    });

//    test('AD bind', () async {
//
//       await ldap.bind();
//    });

    test('AD search', () async {

      //await ldap.bind();

      var f1 = Filter.substring("CN=*");
      //var f2 =  Filter.equals("objectclass", "inetOrgPerson");
      var f2 =  Filter.equals("objectclass", "person");
      //var f2 =  Filter.equals("CN", "foo");

      // equiv ldapsearch
      //ldapsearch -p 2389 -h localhost -D "cn=Directory Manager" -w password \
      //  -b "dc=example,dc=com" -a always \
      //  -s sub "(CN=foo)" dn objectClass
      //


        var result = ldap.search("CN=Users,DC=openrock,DC=org", f2, ["dn","objectClass"],sizeLimit:100).stream;
        //var result = ldap.search("dc=example,dc=com", f2, ["dn","objectClass"], sizeLimit:0).stream;
        //var result = ldap.search("DC=openrock,DC=org", f2, []).stream;

        int count = 0;
        var f = result.listen( (entry) {
          ++count;
          print(entry);
        },
        onDone: () {
          print("count=$count");
          },
        onError: (e) {});

      return f;

    });
  });
}
